<?php
/*
Plugin Name: MoneyBird API integration [Woosa Bol.com add-on]
Plugin URI: https://extensiontree.com/nl/producten/woocommerce-extensies/moneybird-api-koppeling/
Version: 1.0.0
Author: Marco Cox, <a href="https://extensiontree.com/nl/">ExtensionTree.com</a>
Description: Adds extra options to the MoneyBird plugin for bol.com orders.
Requires at least: 3.8
Tested up to: 5.4.2
WC requires at least: 2.2.0
WC tested up to: 4.3.0
*/

if (!defined('ABSPATH')) exit; // Exit if accessed directly

include_once( ABSPATH . 'wp-admin/includes/plugin.php' );

if (is_plugin_active( 'woocommerce/woocommerce.php')) {

    function insert_woocommerce_moneybird_bol_integration($integrations) {
        if (in_array('WC_MoneyBird2', $integrations)) {
            $integrations[array_search('WC_MoneyBird2', $integrations)] = 'WC_MoneyBird_Bol';
        }

        return $integrations;
    }

    add_filter('woocommerce_integrations', 'insert_woocommerce_moneybird_bol_integration', 20);


    function woocommerce_moneybird_bol_init() {
        require_once('class-wc-moneybird-bol.php');
    }

    add_action('plugins_loaded', 'woocommerce_moneybird_bol_init', 20);


    function wc_mb_bol_modify_invoice($invoice, $order) {
        if (get_post_meta($order->get_id(), '_created_via', true) != 'bol.com') {
            return $invoice;
        }

        $mb = WC()->integrations->integrations['moneybird2'];

        // Change workflow?
        if (isset($mb->settings['bol_workflow_id'])) {
            $workflow_id = $mb->settings['bol_workflow_id'];
            if (!empty($workflow_id)) {
                if ($workflow_id != 'auto') {
                    $invoice['workflow_id'] = $workflow_id;
                } else {
                    if (isset($invoice['workflow_id'])) {
                        unset($invoice['workflow_id']);
                    }
                }
            }
        }

        // Change document style?
        if (isset($mb->settings['bol_document_style_id'])) {
            if (!empty($mb->settings['bol_document_style_id'])) {
                $invoice['document_style_id'] = $mb->settings['bol_document_style_id'];
            }
        }

        return $invoice;
    }

    add_filter('woocommerce_moneybird_invoice', 'wc_mb_bol_modify_invoice', 10, 2);


    function wc_mb_bol_modify_register_payment($register_payment, $order) {
        if (get_post_meta($order->get_id(), '_created_via', true) != 'bol.com') {
            return $register_payment;
        }

        $mb = WC()->integrations->integrations['moneybird2'];

        if (isset($mb->settings['bol_always_mark_paid'])) {
            if ($mb->settings['bol_always_mark_paid'] == 'yes') {
                $register_payment = true;
            }
        }

        return $register_payment;
    }

    add_filter('woocommerce_moneybird_register_payment', 'wc_mb_bol_modify_register_payment', 10, 2);


    function wc_mb_bol_modify_order_is_paid($order_is_paid, $order) {
        if (get_post_meta($order->get_id(), '_created_via', true) != 'bol.com') {
            return $order_is_paid;
        }

        $mb = WC()->integrations->integrations['moneybird2'];

        if (isset($mb->settings['bol_always_mark_paid'])) {
            if ($mb->settings['bol_always_mark_paid'] == 'yes') {
                $order_is_paid = true;
            }
        }

        return $order_is_paid;
    }

    add_filter('woocommerce_moneybird_is_order_paid', 'wc_mb_bol_modify_order_is_paid', 10, 2);


    function wc_mb_bol_modify_sendmode($sendmode, $order) {
        if (get_post_meta($order->get_id(), '_created_via', true) != 'bol.com') {
            return $sendmode;
        }

        $mb = WC()->integrations->integrations['moneybird2'];

        if (isset($mb->settings['bol_never_send'])) {
            if ($mb->settings['bol_never_send'] == 'yes') {
                if ($sendmode != 'draft') {
                    $sendmode = 'Manual';
                }
            }
        }

        return $sendmode;
    }


    add_filter('woocommerce_moneybird_sendmode', 'wc_mb_bol_modify_sendmode', 10, 2);

} // if woocommerce active